# Isa
<p >
    Isa : Python module that translates a number 
    into Malagasy🇲🇬 letters  </br> </br>
    Author : rivo2302 | www.rivo.iteam-s.mg
</p>

<h1 align=center><img src="https://readme-typing-svg.herokuapp.com?font=jetbrains+mono&color=%teal&size=23&center=true&vCenter=true&lines=ISA%2C+Number%2C+into%2C+Malagasy🇲🇬%2C+letters" alt="Description">
</h1>



## Dependencies:
- [Python 2.7+](https://www.python.org/)

## Installation

```s
pip install Hisa
```
## Usage

```s
from hisa import Hisa

letters = Hisa(155)
print(letters)
```

###### Response
```s
dimy amby dimampolo amby zato
```

<div align="center">
<img src="https://img.shields.io/badge/-Python-396E9B?style=for-the-badge&logo=python&logoColor=FFFFFF"/> 
</div>